@@ -150,7 +150,72 @@ void EnsembleModel::Compute_Coef(arma::uword& group) {
   // Cache step size computation - only compute once per subspace
   if (cached_step_sizes[group] < 0 || !subspace_cache_valid[group]) {
     arma::mat XtX = x_subset.t() * x_subset;
-    cached_step_sizes[group] = 1.0 / arma::max(arma::eig_sym(XtX));
+    
+    // ROBUST STEP SIZE COMPUTATION WITH MULTIPLE FALLBACKS
+    bool step_size_computed = false;
+    
+    // Method 1: Try original eig_sym approach
+    try {
+      arma::vec eigenvals = arma::eig_sym(XtX);
+      double max_eig = arma::max(eigenvals);
+      if (max_eig > 1e-12 && arma::is_finite(max_eig)) {
+        cached_step_sizes[group] = 1.0 / max_eig;
+        step_size_computed = true;
+      }
+    } catch (...) {
+      // eig_sym failed, continue to next method
+    }
+    
+    // Method 2: Try with regularization if original failed
+    if (!step_size_computed) {
+      try {
+        arma::mat XtX_reg = XtX;
+        XtX_reg.diag() += 1e-8;
+        arma::vec eigenvals = arma::eig_sym(XtX_reg);
+        double max_eig = arma::max(eigenvals);
+        if (max_eig > 1e-12 && arma::is_finite(max_eig)) {
+          cached_step_sizes[group] = 1.0 / max_eig;
+          step_size_computed = true;
+        }
+      } catch (...) {
+        // Regularized eig_sym also failed, continue to next method
+      }
+    }
+    
+    // Method 3: Try SVD approach
+    if (!step_size_computed) {
+      try {
+        arma::vec singular_values;
+        bool svd_success = arma::svd(singular_values, XtX);
+        if (svd_success && singular_values.n_elem > 0 && 
+            singular_values(0) > 1e-12 && arma::is_finite(singular_values(0))) {
+          cached_step_sizes[group] = 1.0 / singular_values(0);
+          step_size_computed = true;
+        }
+      } catch (...) {
+        // SVD also failed, continue to fallback
+      }
+    }
+    
+    // Method 4: Trace-based fallback
+    if (!step_size_computed) {
+      try {
+        double trace_val = arma::trace(XtX);
+        if (trace_val > 1e-12 && arma::is_finite(trace_val) && XtX.n_rows > 0) {
+          double avg_eigenval = trace_val / XtX.n_rows;
+          cached_step_sizes[group] = 1.0 / avg_eigenval;
+          step_size_computed = true;
+        }
+      } catch (...) {
+        // Even trace failed
+      }
+    }
+    
+    // Method 5: Ultimate conservative fallback
+    if (!step_size_computed) {
+      cached_step_sizes[group] = 1e-15;  // Very conservative step size
+    }
+    
     subspace_cache_valid[group] = true;
   }
   step_size_coef = cached_step_sizes[group];
@@ -223,9 +288,71 @@ void EnsembleModel::Compute_Coef_Candidate(arma::uword& group) {
   arma::uvec model_subspace = Get_Model_Subspace_Candidate(group);
   arma::mat x_subset = x_sc.cols(model_subspace);
   
-  // Compute step size (no caching for candidate since it's temporary)
+  // ROBUST STEP SIZE COMPUTATION WITH MULTIPLE FALLBACKS
   arma::mat XtX = x_subset.t() * x_subset;
-  step_size_coef = 1 / arma::max(arma::eig_sym(XtX));
+  bool step_size_computed = false;
+  
+  // Method 1: Try original eig_sym approach
+  try {
+    arma::vec eigenvals = arma::eig_sym(XtX);
+    double max_eig = arma::max(eigenvals);
+    if (max_eig > 1e-12 && arma::is_finite(max_eig)) {
+      step_size_coef = 1.0 / max_eig;
+      step_size_computed = true;
+    }
+  } catch (...) {
+    // eig_sym failed, continue to next method
+  }
+  
+  // Method 2: Try with regularization if original failed
+  if (!step_size_computed) {
+    try {
+      arma::mat XtX_reg = XtX;
+      XtX_reg.diag() += 1e-8;
+      arma::vec eigenvals = arma::eig_sym(XtX_reg);
+      double max_eig = arma::max(eigenvals);
+      if (max_eig > 1e-12 && arma::is_finite(max_eig)) {
+        step_size_coef = 1.0 / max_eig;
+        step_size_computed = true;
+      }
+    } catch (...) {
+      // Regularized eig_sym also failed, continue to next method
+    }
+  }
+  
+  // Method 3: Try SVD approach
+  if (!step_size_computed) {
+    try {
+      arma::vec singular_values;
+      bool svd_success = arma::svd(singular_values, XtX);
+      if (svd_success && singular_values.n_elem > 0 && 
+          singular_values(0) > 1e-12 && arma::is_finite(singular_values(0))) {
+        step_size_coef = 1.0 / singular_values(0);
+        step_size_computed = true;
+      }
+    } catch (...) {
+      // SVD also failed, continue to fallback
+    }
+  }
+  
+  // Method 4: Trace-based fallback
+  if (!step_size_computed) {
+    try {
+      double trace_val = arma::trace(XtX);
+      if (trace_val > 1e-12 && arma::is_finite(trace_val) && XtX.n_rows > 0) {
+        double avg_eigenval = trace_val / XtX.n_rows;
+        step_size_coef = 1.0 / avg_eigenval;
+        step_size_computed = true;
+      }
+    } catch (...) {
+      // Even trace failed
+    }
+  }
+  
+  // Method 5: Ultimate conservative fallback
+  if (!step_size_computed) {
+    step_size_coef = 0.01;  // Very conservative step size
+  }
   
   arma::vec betas = arma::zeros(x_subset.n_cols);
   arma::vec new_betas = betas;
@@ -453,9 +580,13 @@ double EnsembleModel::Get_Ensemble_Loss() {
 }
 arma::vec EnsembleModel::Prediction_Residuals_Ensemble(arma::mat& x_test, arma::vec& y_test) {
   
+  return (y_test - arma::mean(final_intercept) - arma::mean(x_test * final_coef, 1));
+}
+arma::vec EnsembleModel::Prediction_Square_Residuals_Ensemble(arma::mat& x_test, arma::vec& y_test) {
+  
   return arma::square(y_test - arma::mean(final_intercept) - arma::mean(x_test * final_coef, 1));
 }
-arma::vec EnsembleModel::Prediction_Residuals_Models(arma::mat& x_test, arma::vec& y_test) {
+arma::vec EnsembleModel::Prediction_Square_Residuals_Models(arma::mat& x_test, arma::vec& y_test) {
   
   arma::vec prediction_residuals = arma::zeros(y_test.n_elem);
   for (arma::uword group = 0; group < n_models; group++) {
