@@ -40,7 +40,7 @@ private:
   arma::umat active_samples, active_samples_candidate;
   arma::uvec subset_active;
   arma::uvec subset_active_samples;
-  arma::uvec group_vec;
+  arma::uvec group_vec; 
   arma::mat final_coef, final_coef_candidate;
   arma::vec final_intercept, final_intercept_candidate;
   arma::vec models_loss, models_loss_candidate;
@@ -103,7 +103,8 @@ public:
   arma::mat Get_Final_Coef();
   double Get_Ensemble_Loss();
   arma::vec Prediction_Residuals_Ensemble(arma::mat& x_test, arma::vec& y_test);
-  arma::vec Prediction_Residuals_Models(arma::mat& x_test, arma::vec& y_test);
+  arma::vec Prediction_Square_Residuals_Ensemble(arma::mat& x_test, arma::vec& y_test);
+  arma::vec Prediction_Square_Residuals_Models(arma::mat& x_test, arma::vec& y_test);
 };
 
 #endif // EnsembleModel_hpp
